@@ -10,12 +10,14 @@ from .account import account
 from .friends import friends
 from .groups import groups
 from .messages import messages
+from .ovk import ovk
 from .utils import utils
 from .users import users
 from .news_feed import news_feed
 from .wall import wall
+from .likes import likes
 
 
 __author__ = 'Parliskaya'
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 __email__ = 'alonaparlis@gmail.com'
\ No newline at end of file
